``` bash
python scripts/oef/launch.py -c ./scripts/oef/launch_config.json
```
``` bash
svn export https://github.com/fetchai/agents-aea.git/trunk/examples
svn export https://github.com/fetchai/agents-aea.git/trunk/scripts
```
